Index: chrome/browser/autocomplete/autocomplete.cc |
diff --git a/chrome/browser/autocomplete/autocomplete.cc b/chrome/browser/autocomplete/autocomplete.cc |
index 01d36fa3250465e3fb9e4914b5e126bf3cba308c..66a91a6fb264db9d244081fb964a51a0ff2b6f57 100644 |
--- a/chrome/browser/autocomplete/autocomplete.cc |
+++ b/chrome/browser/autocomplete/autocomplete.cc |
@@ -148,13 +148,13 @@ AutocompleteInput::Type AutocompleteInput::Parse( |
if (parts->scheme.is_nonempty() && |
(parsed_scheme != L"http") && (parsed_scheme != L"https")) { |
// See if we know how to handle the URL internally. |
- if (URLRequest::IsHandledProtocol(WideToASCII(parsed_scheme))) |
+ if (net::URLRequest::IsHandledProtocol(WideToASCII(parsed_scheme))) |
return URL; |
// There are also some schemes that we convert to other things before they |
// reach the renderer or else the renderer handles internally without |
// reaching the URLRequest logic. We thus won't catch these above, but we |
// should still claim to handle them. |
if (LowerCaseEqualsASCII(parsed_scheme, chrome::kViewSourceScheme) || |
LowerCaseEqualsASCII(parsed_scheme, chrome::kJavaScriptScheme) || |
LowerCaseEqualsASCII(parsed_scheme, chrome::kDataScheme)) |
@@ -148,13 +148,13 @@ AutocompleteInput::Type AutocompleteInput::Parse( |
// There are also some schemes that we convert to other things before they |
// reach the renderer or else the renderer handles internally without |
- // reaching the URLRequest logic. We thus won't catch these above, but we |
- // should still claim to handle them. |
+ // reaching the net::URLRequest logic. We thus won't catch these above, but |
+ // we should still claim to handle them. |
if (LowerCaseEqualsASCII(parsed_scheme, chrome::kViewSourceScheme) || |
LowerCaseEqualsASCII(parsed_scheme, chrome::kJavaScriptScheme) || |